"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const chai_1 = require("chai");
const child_process_1 = require("child_process");
const cli_ux_1 = require("cli-ux");
const fs = require("fs");
const inquirer = require("inquirer");
const path = require("path");
const sinon = require("sinon");
const util = require("util");
const originCwd = process.cwd();
const { resolve } = path;
const asyncExec = util.promisify(child_process_1.exec);
const sandbox = sinon.createSandbox();
const rdtName = 'test-rdt';
const cmdDir = resolve('./src/commands');
let CmdCreate = require(resolve(cmdDir, './template/create.ts')).default;
describe('rde template:create', () => {
    describe('create using a starter', () => {
        before(async () => {
            await asyncExec('rm -rf ./test/run && mkdir ./test/run');
            process.chdir('./test/run');
            sandbox.stub(inquirer, 'prompt').resolves({ framework: 'vue', byExtend: false });
            await CmdCreate.run([rdtName]);
        });
        after(() => {
            process.chdir(originCwd);
            sandbox.restore();
        });
        it('should has a proper project structure', () => {
            chai_1.expect(fs.existsSync('app')).to.be.true;
            chai_1.expect(fs.existsSync('template')).to.be.true;
            chai_1.expect(fs.existsSync('package.json')).to.be.true;
            chai_1.expect(fs.existsSync('rde.template.js')).to.be.true;
        });
    });
    describe('create using extend a existing rdt package', () => {
        before(async () => {
            await asyncExec('rm -rf ./test/run && mkdir ./test/run');
            process.chdir('./test/run');
            sandbox.stub(inquirer, 'prompt').resolves({ framework: 'vue', byExtend: true });
            const promptStub = async () => '@rede/rdt-vue-starter';
            sandbox.stub(cli_ux_1.default, 'prompt').get(() => promptStub);
            await CmdCreate.run([rdtName]);
        });
        after(() => {
            process.chdir(originCwd);
            sandbox.restore();
        });
        it('should has a proper project structure', () => {
            chai_1.expect(fs.existsSync('node_modules')).to.be.true;
            chai_1.expect(fs.existsSync('README.md')).to.be.true;
            chai_1.expect(fs.existsSync('package.json')).to.be.true;
            chai_1.expect(fs.existsSync('rde.template.js')).to.be.true;
        });
    });
});
