"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const extend = require("deep-extend");
const fs = require("fs");
const path = require("path");
const copy = require("recursive-copy");
const conf_1 = require("../services/conf");
const logger_1 = require("../services/logger");
const render_1 = require("../services/render");
const watcher_1 = require("../services/watcher");
const util_1 = require("../util");
const { resolve } = path;
class DockerRun {
    constructor({ watch }) {
        this.watch = watch;
    }
    async start() {
        let config;
        // generate rdt template from rdt chain
        config = await this.copyToTmp();
        // template render to .rde
        await this.renderDir(conf_1.default.tmpDir, config);
        // start watcher
        await this.composeRde(config);
    }
    async copyToTmp() {
        const { cwd, tmpDir, appConfName, rdcConfName, runtimeDir, rdeDir, } = conf_1.default;
        await util_1.default.asyncExec(`rm -rf ${tmpDir} && mkdir ${tmpDir}`);
        let config = require(resolve(cwd, rdcConfName));
        const rdaConfPath = resolve(cwd, appConfName);
        if (fs.existsSync(rdaConfPath)) {
            config = extend(config, require(rdaConfPath));
        }
        let srcDir = resolve(cwd, runtimeDir);
        logger_1.debug(`copying files from ${srcDir} to ${resolve(tmpDir, runtimeDir)}`);
        await copy(srcDir, resolve(tmpDir, runtimeDir), {
            overwrite: true,
            dot: true,
            filter(filePath) {
                return !filePath.includes('node_modules');
            },
        });
        await render_1.default.renderTo('module', {
            obj: config
        }, resolve(rdeDir, rdcConfName), {
            overwrite: true
        });
        return config;
    }
    async renderDir(dir, config) {
        const srcDir = resolve(dir, conf_1.default.runtimeDir);
        // @ts-ignore
        const { render: rdtRender = {}, container, suites } = config;
        const { includes = [] } = rdtRender;
        if (suites && suites.length) {
            container.render.suites = suites;
        }
        const dataView = container ? container.render : rdtRender.dev ? rdtRender.dev.render : {};
        await render_1.default.renderDir(srcDir, Object.assign({}, dataView), includes, conf_1.default.rdeDir, {
            overwrite: true,
            dot: true
        });
        await util_1.default.asyncExec(`rm -rf ${dir}`);
    }
    async composeRde(config) {
        const { cwd, rdeDir, rdType, RdTypes } = conf_1.default;
        logger_1.debug(`merged mappings: ${JSON.stringify(config.mappings)}`);
        for (let { from, to, options } of config.mappings) {
            const appDir = resolve(cwd, from);
            const destDir = resolve(rdeDir, to);
            await util_1.default.copy(appDir, destDir, { options });
        }
        if (this.watch) {
            let { mappings } = config;
            if (rdType === RdTypes.Container) {
                mappings = mappings.concat([{
                        from: conf_1.default.runtimeDir,
                        to: '.'
                    }]);
            }
            new watcher_1.default(mappings).start();
        }
    }
}
exports.default = DockerRun;
