"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require("fs");
const path = require("path");
const writePkg = require("write-pkg");
const conf_1 = require("../services/conf");
const docker_1 = require("../services/docker");
const util_1 = require("../util");
const message_1 = require("./message");
const { resolve } = path;
class Install {
    get appConf() {
        return require(resolve(conf_1.default.cwd, conf_1.default.appConfName));
    }
    async app({ rdc = null, skipInstall = false, }) {
        /**
         * copy:
         * 1. runtime dir to local
         * 1. rdc.config.js
         * then:
         * 1. install pkg.json if container
         * 1. add suite to pkg.json then install if app
         */
        const { cwd, runtimeDir, rdcConfName, dockerWorkDirRoot, localCacheDir, } = conf_1.default;
        // only create application will pass rdc param
        if (!rdc) {
            rdc = this.appConf.container.name;
        }
        const name = rdc.split(':')[0];
        const rdcPathInDock = resolve(dockerWorkDirRoot, name);
        await docker_1.default.copy(rdc, [{
                from: resolve(rdcPathInDock, runtimeDir),
                to: cwd,
            }, {
                from: resolve(rdcPathInDock, rdcConfName),
                to: localCacheDir,
            }]);
        const runtimePkgJson = require(resolve(cwd, runtimeDir, 'package.json'));
        const cachePkgJsonPath = resolve(localCacheDir, 'package.json');
        const symPkgJsonPath = resolve(cwd, 'package.json');
        if (!rdc) {
            this.appConf.suites.map(item => {
                runtimePkgJson.dependencies = runtimePkgJson.dependencies || {};
                runtimePkgJson.dependencies[item.name] = item.version;
            });
        }
        await writePkg(resolve(localCacheDir), runtimePkgJson);
        if (!skipInstall) {
            fs.symlinkSync(cachePkgJsonPath, symPkgJsonPath);
            await util_1.default.asyncSpawn('npm', ['i', '--package-lock', 'false'], {
                cwd,
            });
            fs.unlinkSync(symPkgJsonPath);
        }
    }
    async pkg(type) {
        const { cwd, RdTypes, runtimeDir, localCacheDir, } = conf_1.default;
        if (type === RdTypes.Application) {
            const cachePkgJsonPath = resolve(localCacheDir, 'package.json');
            if (!fs.existsSync(cachePkgJsonPath)) {
                throw Error(message_1.MRDA.NO_PKG_IN_CACHE_DIR);
            }
            const symPkgJsonPath = resolve(cwd, 'package.json');
            fs.symlinkSync(cachePkgJsonPath, symPkgJsonPath);
            await util_1.default.asyncSpawn('npm', ['i', '--package-lock', 'false'], {
                cwd,
            });
            fs.unlinkSync(symPkgJsonPath);
        }
        if (type === RdTypes.Container) {
            const runtimePkgJsonPath = resolve(runtimeDir, 'package.json');
            const symPkgJsonPath = resolve(cwd, 'package.json');
            fs.symlinkSync(runtimePkgJsonPath, symPkgJsonPath);
            await util_1.default.asyncSpawn('npm', ['i', '--package-lock', 'false'], {
                cwd,
            });
            fs.unlinkSync(symPkgJsonPath);
        }
    }
}
exports.default = new Install();
