"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const chai_1 = require("chai");
const child_process_1 = require("child_process");
const util = require("util");
const npm_1 = require("../../src/services/npm");
const asyncExec = util.promisify(child_process_1.exec);
describe('npm', () => {
    describe('getInfo', () => {
        it('should return correct npm info if exist', async () => {
            const result = await npm_1.default.getInfo('nek-ui');
            chai_1.expect(result.name).to.equal('nek-ui');
        });
        it('should throw an error if not exist', async () => {
            const pkg = await npm_1.default.getInfo('some-unexist-pkg-of-kaola');
            chai_1.expect(pkg).to.be.null;
        });
    });
    describe('install', () => {
        before(async () => {
            await asyncExec('mkdir ./test/run && cd ./test/run && npm init -y');
        });
        after(async () => {
            await asyncExec('rm -rf ./test/run');
        });
        it('should be installed if package exist', async () => {
            await npm_1.default.install('nek-ui', true, './test/run');
            const pkgJson = require(`${process.cwd()}/test/run/package.json`);
            chai_1.expect(pkgJson.devDependencies['nek-ui']).to.not.be.undefined;
        });
        it('should be failed if package not exist', async () => {
            await npm_1.default.install('some-unexist-pkg-of-kaola', true, './test/run');
            const pkgJson = require(`${process.cwd()}/test/run/package.json`);
            chai_1.expect(pkgJson.devDependencies['nek-ui']).to.not.undefined;
        });
    });
});
